# -*- coding: utf-8 -*-
from hangulize import *


class Bulgarian(Language):
    """For transcribing Bulgarian."""

    __iso639__ = {1: 'bg', 2: 'bul', 3: 'bul'}
    __tmp__ = ',;'

    vowels = u'аеийоуъьюя'
    cs = u'бвгджзклмнпрстфхцчшщ'
    vl = u'кпстфхцчшщ'
    notation = Notation([
        (u'град', u'град-'),
        (u'бб', u'б'),
        (u'вв', u'в'),
        (u'вф', u'ф'),
        (u'гг', u'г'),
        (u'дд', u'д'),
        (u'дц', u'ц'),
        (u'дч', u'ч'),
        (u'жж', u'ж'),
        (u'зз', u'з'),
        (u'зс', u'с'),
        (u'кк', u'к'),
        (u'лл', u'л'),
        (u'{@}мм{@}', u'м,м'),
        (u'мм', u'м'),
        (u'{@}нн{@}', u'н,н'),
        (u'нн', u'н'),
        (u'пп', u'п'),
        (u'рр', u'р'),
        (u'сс', u'с'),
        (u'тт', u'т'),
        (u'тц', u'ц'),
        (u'тч', u'ч'),
        (u'фф', u'ф'),
        (u'хх', u'х'),
        (u'цц', u'ц'),
        (u'чч', u'ч'),
        (u'шш', u'ш'),
        (u'щ', u'шт'),
        (u'ий', u'и'),
        (u'дс$', u'ц'),
        (u'дс{<cs>}', u'ц'),
        (u'тс', u'ц'),
        (u'дз', u'з'),
        (u'нкт', u'Nт'),
        (u'б{<vl>}', u'п'),
        (u'б$', u'п'),
        (u'в{<vl>}', u'ф'),
        (u'в$', u'ф'),
        (u'г{<vl>}', u'к'),
        (u'г$', u'к'),
        (u'д{<vl>}', u'т'),
        (u'д$', u'т'),
        (u'дж{<vl>}', u'ч'),
        (u'дж$', u'ч'),
        (u'ж{<vl>}', u'ш'),
        (u'ж$', u'ш'),
        (u'з{<vl>}', u'с'),
        (u'з$', u'с'),
        (u'б{<vl>}', u'п'),
        (u'в{<vl>}', u'ф'),
        (u'г{<vl>}', u'к'),
        (u'д{<vl>}', u'т'),
        (u'дж{<vl>}', u'ч'),
        (u'ж{<vl>}', u'ш'),
        (u'з{<vl>}', u'с'),
        (u'^к', u'к;'),
        (u'{<cs>}к', u'к;'),
        (u'к{<vl>}', u'к,'),
        (u'^п', u'п;'),
        (u'{<cs>}п', u'п;'),
        (u'п{<vl>}', u'п,'),
        (u';', None),
        (u'ш{<cs>}', u'сю'),
        (u'ш$', u'си'),
        (u'ш', u'сь'),
        (u'^й{@}', u'ь'),
        (u'{@}й{@}', u'ь'),
        (u'й', u'и'),
        (u'ю', u'ьу'),
        (u'я', u'ьа'),
        (u'{ж|з|ц|ч}ь', None),
        (u'ше', u'сье'),
        (u'сье', u'с-ье'),
        (u'{<cs>}ье', u'е'),
        (u'дж{<cs>}', u'жи'),
        (u'дж', u'ж'),
        (u'ж{<cs>}', u'жу'),
        (u'ч$', u'чи'),
        (u'ч{<cs>}', u'чи'),
        (u'^л', u'л;'),
        (u'^м', u'м;'),
        (u'^н', u'н;'),
        (u'л$', u'л,'),
        (u'м$', u'м,'),
        (u'н$', u'н,'),
        (u'л{@|м,|н,}', u'л;'),
        (u'м{@}', u'м;'),
        (u'н{@}', u'н;'),
        (u'л', u'л,'),
        (u'м', u'м,'),
        (u'н', u'н,'),
        (u',,', u','),
        (u',;', None),
        (u',л,', u'л,'),
        (u',м,', u'м,'),
        (u',н,', u'н,'),
        (u'л{м;|н;}', u'л,'),
        (u';|-', None),
        (u'б', Choseong(B)),
        (u'в', Choseong(B)),
        (u'г', Choseong(G)),
        (u'д', Choseong(D)),
        (u'ж', Choseong(J)),
        (u'з', Choseong(J)),
        (u'ж', Choseong(J)),
        (u'к,', Jongseong(G)),
        (u'к', Choseong(K)),
        (u'^л', Choseong(L)),
        (u'{,}л', Choseong(L)),
        (u'л,', Jongseong(L)),
        (u'л', Jongseong(L), Choseong(L)),
        (u'м,', Jongseong(M)),
        (u'м', Choseong(M)),
        (u'н,', Jongseong(N)),
        (u'н', Choseong(N)),
        (u'N', Jongseong(NG)),
        (u'п,', Jongseong(B)),
        (u'п', Choseong(P)),
        (u'р', Choseong(L)),
        (u'с', Choseong(S)),
        (u'т', Choseong(T)),
        (u'ф', Choseong(P)),
        (u'х', Choseong(H)),
        (u'ц', Choseong(C)),
        (u'ч', Choseong(C)),
        (u'ьа', Jungseong(YA)),
        (u'ье', Jungseong(YE)),
        (u'ьи', Jungseong(I)),
        (u'ьо', Jungseong(YO)),
        (u'ьу', Jungseong(YU)),
        (u'ьъ', Jungseong(YEO)),
        (u'а', Jungseong(A)),
        (u'е', Jungseong(E)),
        (u'и', Jungseong(I)),
        (u'о', Jungseong(O)),
        (u'у', Jungseong(U)),
        (u'ъ', Jungseong(EO))
    ])

    def normalize(self, string):
        return normalize_roman(string, {
            u'А': u'а', u'Б': u'б', u'В': u'в', u'Г': u'г', u'Д': u'д',
            u'Е': u'е', u'Ж': u'ж', u'З': u'з', u'И': u'и', u'Й': u'й',
            u'К': u'к', u'Л': u'л', u'М': u'м', u'Н': u'н', u'О': u'о',
            u'П': u'п', u'Р': u'р', u'С': u'с', u'Т': u'т', u'У': u'у',
            u'Ф': u'ф', u'Х': u'х', u'Ц': u'ц', u'Ч': u'ч', u'Ш': u'ш',
            u'Щ': u'щ', u'Ъ': u'ъ', u'Ь': u'ь', u'Ю': u'ю', u'Я': u'я'
        })


__lang__ = Bulgarian
