# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class Czech(Language):
    """For transcribing Czech."""

    __iso639__ = {1: 'cs', 2: 'cze', 3: 'ces'}
    __tmp__ = ',;'

    vowels = 'aeiouy'
    vl = 'cCfHkpsStT' # voiceless obstruents
    notation = Notation([
        (u'č',         'C'),
        (u'ď',         'D'),
        (u'ě',         'je'),
        (u'ň',         'N'),
        (u'ř',         'rZ'),
        (u'š',         'S'),
        (u'ť',         'T'),
        (u'ž',         'Z'),
        ('w',          'v'),
        ('b{<vl>}',    'p'),
        ('b$',         'p'),
        ('d{<vl>}',    't'),
        ('d$',         't'),
        ('D{<vl>}',    'T'),
        ('D$',         'T'),
        ('g{<vl>}',    'k'),
        ('g$',         'k'),
        ('v{<vl>}',    'f'),
        ('v$',         'f'),
        ('z{<vl>}',    's'),
        ('z$',         's'),
        ('Z{<vl>}',    'S'),
        ('Z$',         'S'),
        ('D{@}',       'dJ'),
        ('D',          'di'),
        ('N{@}',       'nJ'),
        ('N',          'n'),
        ('S{@}',       'sJ'),
        ('S$',         'si'),
        ('S',          'sJu'),
        ('T{@}',       'tJ'),
        ('T',          'ti'),
        ('Z{@}',       'z'),
        ('Z',          'zu'),
        ('xx',         'x'),
        ('^x',         'z'),
        ('x',          'ks'),
        ('qu',         'kv'),
        ('q',          'k'),
        ('ch',         'H'),
        ('aa',         'a'),
        ('bb',         'b'),
        ('dd',         'd'),
        ('ee',         'e'),
        ('ff',         'f'),
        ('gg',         'g'),
        ('hh',         'h'),
        ('jj',         'ij'),
        ('ii',         'i'),
        ('^j{@}',      'J'),
        ('{@}j{@}',    'J'),
        ('sje',        'sJe'),
        ('je',         'e'),
        ('{n|d|s|t}j', 'J'),
        ('j',          'i'),
        ('ij',         'i'),
        ('yj',         'y'),
        ('kk',         'k'),
        ('ll',         'l'),
        ('{@}mm{@}',   'm,m'),
        ('mm',         'm'),
        ('{@}nn{@}',   'n,n'),
        ('nn',         'n'),
        ('oo',         'o'),
        ('pp',         'p'),
        ('rr',         'r'),
        ('ss',         's'),
        ('tt',         't'),
        ('uu',         'u'),
        ('vv',         'v'),
        ('^y{@}',      'J'),
        ('yy',         'y'),
        ('y',          'i'),
        ('zz',         'z'),
        ('{l|m|n}j$',  None),
        ('je',         'e'),
        ('^l',         'l;'),
        ('^m',         'm;'),
        ('^n',         'n;'),
        ('l$',         'l,'),
        ('m$',         'm,'),
        ('n$',         'n,'),
        ('l{@|m,|n,}', 'l;'),
        ('{,}l',       'l;'),
        ('m{@|r}',     'm;'),
        ('n{@|J}',     'n;'),
        ('l',          'l,'),
        ('m',          'm,'),
        ('n',          'n,'),
        (',,',         ','),
        (',;',         None),
        (',l,',        'l,'),
        (',m,',        'm,'),
        (',n,',        'n,'),
        ('l{m;|n;}',   'l,'),
        (';',          None),       
        ('{@}k{<vl>}', 'k,'),
        ('{@}p{<vl>}', 'p,'),
        ('C{@}',       Choseong(C)),
        ('C',          Choseong(C), Jungseong(I)),
        ('b',          Choseong(B)),
        ('c',          Choseong(C)),
        ('d',          Choseong(D)),
        ('f',          Choseong(P)),
        ('g',          Choseong(G)),
        ('h',          Choseong(H)),
        ('H',          Choseong(H)),
        ('k,',         Jongseong(G)),
        ('k',          Choseong(K)),
        ('^l',         Choseong(L)),
        ('{,}l',       Choseong(L)),
        ('l,',         Jongseong(L)),
        ('l',          Jongseong(L), Choseong(L)),
        ('m,',         Jongseong(M)),
        ('m',          Choseong(M)),
        ('n,',         Jongseong(N)),
        ('n',          Choseong(N)),
        ('p,',         Jongseong(B)),
        ('p',          Choseong(P)),
        ('r',          Choseong(L)),
        ('s',          Choseong(S)),
        ('t',          Choseong(T)),
        ('v',          Choseong(B)),
        ('z',          Choseong(J)),
        ('Ja',         Jungseong(YA)),
        ('Je',         Jungseong(YE)),
        ('Ji',         Jungseong(I)),
        ('Jo',         Jungseong(YO)),
        ('Ju',         Jungseong(YU)),
        ('a',          Jungseong(A)),
        ('e',          Jungseong(E)),
        ('i',          Jungseong(I)),
        ('o',          Jungseong(O)),
        ('u',          Jungseong(U))
    ])

    def normalize(self, string):
        return normalize_roman(string, {
            u'Č': u'č', u'Ď': u'ď', u'Ě': u'ě', u'Ň': u'ň', u'Ř': u'ř',
            u'Š': u'š', u'Ť': u'ť', u'Ž': u'ž'
        })


__lang__ = Czech
