# -*- coding: utf-8 -*-
from hangulize import *


class Welsh(Language):
    """For transcribing Welsh."""

    __iso639__ = {1: 'cy', 2: 'wel', 3: 'cym'}
    __tmp__ = ',;'

    vowels = u'aeiîouUwŵyŷQ'
    cs = 'bcCdDfFghklLmnNpqrstTvWxz,-Y'
    ob = 'bcCdDfFghkpqstTvWxz'
    vl = 'cCFhkpst'
    notation = Notation([
        ('afon', 'afon-'),
        ('banc', 'baNc'),
        ('^ban', 'ban-'),
        ('^fan', 'fan-'),
        ('^man', 'man-'),
        ('blaen', 'blaen-'),
        ('flaen', 'flaen-'),
        ('mlaen', 'mlaen-'),
        ('bron', 'bron-'),
        ('fron', 'fron-'),
        ('mron', 'mron-'),
        ('bryn', 'bryn-'),
        ('fryn', 'fryn-'),
        ('mryn', 'mryn-'),
        ('glan', 'glan-'),
        ('^lan', 'lan-'),
        ('glyn', 'glyn-'),
        ('gwen', 'gwen-'),
        ('gwyn', 'gwyn-'),
        ('^lyn', 'lyn-'),
        ('llain', 'llain-'),
        ('llan', 'llan-'),
        ('llyn', 'llyn-'),
        ('maen', 'maen-'),
        ('faen', 'faen-'),
        ('onnen', 'onnen-'),
        ('^pen', 'pen-'),
        ('^ben', 'ben-'),
        ('^phen', 'phen-'),
        ('rhon', 'rhon-'),
        ('rhyn', 'rhyn-'),
        ('waun', 'waun-'),
        ('{<cs>}ng$', 'N'),
        ('{<cs>}ng', 'n-g'),
        ('^dy$', 'dQ'),
        ('^fy$', 'fQ'),
        ('^y$', 'Q'),
        ('^ym$', 'Qm'),
        ('^yn$', 'Qn'),
        ('^yng$', 'Qng'),
        ('^yr$', 'Qr'),
        ('m mh', 'm h'),
        ('m-mh', 'mh'),
        ('{@} mh', 'm h'),
        ('n nh', 'n h'),
        ('n-nh', 'nh'),
        ('{@} nh', 'n h'),
        ('ng ng', 'ng '),
        ('ng-ng', 'ng'),
        ('{@} ng', 'ng '),
        ('{c|C|g|h|@}win$', 'Win'),
        ('{<cs>}win$', 'YWin'),
        ('{c|C|g|h|@}wyn$', 'Win'),
        ('{<cs>}wyn$', 'YWin'),
        ('ch', 'C'),
        ('dd', 'D'),
        ('ff', 'F'),
        ('ll', 'L'),
        ('th', 'T'),
        ('ll', 'L'),
        ('ng', 'N'),
        ('k', 'c'),
        ('qu', 'cw'),
        ('q', 'c'),
        ('n{c|C}', 'N'),
        ('ph', 'F'),
        ('v', 'f'),
        ('x', 's'),
        ('z', 's'),
        ('^rh', 'hr'),
        ('{c|C|F|h|p|s|t|T}rh', 'r'),
        ('{<cs>}rh', 'hr'),
        ('{c|C|F|h|p|s|t|T}L', 'l'),
        ('L', 'hl'),
        ('^w{<cs>}', 'U'),
        ('{<cs>}w$', 'U'),
        ('{<cs>}w{<cs>}', 'U'),
        ('{c|C|g|@}wi', 'Wi'),
        ('{c|C|g|@}wy', 'Wi'),
        ('wi', 'Ui'),
        ('wy', 'Ui'),
        ('^w{@}', 'W'),
        ('{c|C|g|h|@}w{@}', 'W'),
        ('{<cs>}w{@}', 'YW'),
        ('yw$', 'iw'),
        ('yw{<cs>}', 'iw'),
        ('w', 'U'),
        ('-', None),
        ('mm', 'm'),
        ('nn', 'n'),
        ('^l', 'l;'),
        ('^mh', 'm,h'),
        ('^m', 'm;'),
        ('^nh', 'n,h'),
        ('^n', 'n;'),
        ('l$', 'l,'),
        ('m$', 'm,'),
        ('n$', 'n,'),
        ('l{@|m,|n,|N}', 'l;'),
        ('{,}l', 'l;'),
        ('m{@}', 'm;'),
        ('n{@}', 'n;'),
        ('l', 'l,'),
        ('m', 'm,'),
        ('n', 'n,'),
        ('N', 'N,'),
        (',,', ','),
        (',;', None),
        (',l,', 'l,'),
        (',m,', 'm,'),
        (',n,', 'n,'),
        (',N,', 'N,'),
        ('l{m;|n;}', 'l,'),
        (';', None),
        (',Y', ','),
        ('^i{@}', 'J'),
        ('{@|s}i{@}', 'J'),
        (u'ŵ', 'U'),
        (u'î', 'i'),
        (u'ï', 'i'),
        (u'ŷ', 'i'),
        ('u', 'i'),
        ('ae', 'ai'),
        ('oe', 'oi'),
        ('{@}y$', 'i'),
        ('{@}y{<cs>}', 'i'),
        ('bb', 'b'),
        ('cc', 'c'),
        ('gg', 'g'),
        ('hh', 'h'),
        ('jj', 'j'),
        ('pp', 'p'),
        ('rr', 'r'),
        ('ss', 's'),
        ('tt', 't'),
        ('{<cs>}y$', 'i'),
        ('{<cs>}y{(<cs>)}$', 'i'),
        ('{<cs>}y{(<cs>)(<cs>)}$', 'i'),
        ('{<cs>}y{(<cs>)(<cs>)(<cs>)}$', 'i'),
        ('y', 'Q'),
        ('{@}a', '-a'),
        ('{@}e', '-e'),
        ('{i|Q}i', '-i'),
        ('{@}o', '-o'),
        ('^{@}c$', 'c,'),
        ('{(<cs>)(@)}c$', 'c,'),
        ('{@}c{<ob>}', 'c,'),
        ('^{@}t$', 't,'),
        ('{(<cs>)(@)}t$', 't,'),
        ('{@}t{<ob>}', 't,'),
        ('^{@}p$', 'p,'),
        ('{(<cs>)(@)}p$', 'p,'),
        ('{@}p{<ob>}', 'p,'),
        ('b', Choseong(B)),
        ('c,', Jongseong(G)),
        ('c', Choseong(K)),
        ('C', Choseong(H)),
        ('d', Choseong(D)),
        ('D', Choseong(D)),
        ('f', Choseong(B)),
        ('F', Choseong(P)),
        ('g', Choseong(G)),
        ('h', Choseong(H)),
        ('j', Choseong(J)),
        ('^l', Choseong(L)),
        ('{,}l', Choseong(L)),
        ('l,', Jongseong(L)),
        ('l', Jongseong(L), Choseong(L)),
        ('m,', Jongseong(M)),
        ('m', Choseong(M)),
        ('n,', Jongseong(N)),
        ('n', Choseong(N)),
        ('N', Jongseong(NG)),
        ('p,', Jongseong(B)),
        ('p', Choseong(P)),
        ('r', Choseong(L)),
        ('s', Choseong(S)),
        ('t,', Jongseong(S)),
        ('t', Choseong(T)),
        ('T', Choseong(S)),
        ('Ja', Jungseong(YA)),
        ('Je', Jungseong(YE)),
        ('Ji', Jungseong(I)),
        ('Jo', Jungseong(YO)),
        ('JU', Jungseong(YU)),
        ('JQ', Jungseong(YEO)),
        ('Wa', Jungseong(WA)),
        ('We', Jungseong(WE)),
        ('Wi', Jungseong(WI)),
        ('Wo', Jungseong(WEO)),
        ('WU', Jungseong(U)),
        ('WQ', Jungseong(WEO)),
        ('a', Jungseong(A)),
        ('e', Jungseong(E)),
        ('i', Jungseong(I)),
        ('o', Jungseong(O)),
        ('U', Jungseong(U)),
        ('Q', Jungseong(EO)),
        ('Y', Jungseong(EU)),
        ('-|\'', None),
    ])

    def normalize(self, string):
        additional = {u'Ŵ': u'ŵ', u'Î': u'î', u'Ï': u'ï', u'Ŷ': u'ŷ'}
        return normalize_roman(string, additional)


__lang__ = Welsh
