# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class Esperanto(Language):
    """For transcribing Esperanto."""

    __iso639__ = {1: 'eo', 2: 'epo', 3: 'epo'}
    __tmp__ = ',;'

    vowels = 'aeiou'
    ob = 'bcCdfgGhHJkpsStvz'

    notation = Notation([
        ('-',           '/'),
        ('cx',          u'ĉ'),
        ('gx',          u'ĝ'),
        ('hx',          u'ĥ'),
        ('jx',          u'ĵ'),
        ('sx',          u'ŝ'),
        ('ux',          u'ŭ'),
        ('qu',          u'kŭ'),
        ('w',           u'ŭ'),
        ('x',           'ks'),
        ('^y{@}',       'Y'),
        ('{@}y{@}',     'Y'),
        ('iy',          'i'),
        ('y',           'i'),
        (u'ĉ',          'C'),
        (u'ĝ',          'G'),
        (u'ĥ',          'H'),
        (u'ĵ',          'J'),
        (u'ŝ',          'S'),
        (u'ŭ',          'U'),
        ('^j{@}',       'Y'),
        ('{@}j{@}',     'Y'),
        ('ij',          'i'),
        ('{c|C}j{@}',   None),
        ('{G|J|z}j{@}', None),
        ('j',           'i'),
        ('{g|k|h|H}U',  ';U'),
        ('U',           '%U'),
        (';%',          None),
        ('C{@}',        'c'),
        ('C',           'ci'),
        ('J{@}',        'G'),
        ('J',           'Gu'),
        ('S{@}',        'sj'),
        ('S$',          'si'),
        ('S',           'sju'),
        ('{@}k{<ob>}',  'k,'),
        ('{@}p{<ob>}',  'p,'),
        ('{@}t{<ob>}',  't,'),
        ('^l',          'l;'),
        ('^m',          'm;'),
        ('^n',          'n;'),
        ('l$',          'l,'),
        ('m$',          'm,'),
        ('n$',          'n,'),
        ('l{@|m,|n,}',  'l;'),
        ('{,}l',        'l;'),
        ('m{@}',        'm;'),
        ('n{@}',        'n;'),
        ('l',           'l,'),
        ('m',           'm,'),
        ('n',           'n,'),
        (',,',          ','),
        (',;',          None),
        (',l,',         'l,'),
        (',m,',         'm,'),
        (',n,',         'n,'),
        ('l{m;|n;}',    'l,'),
        (';',           None),
        ('b',           (Choseong(B))),
        ('c',           (Choseong(C))),
        ('d',           (Choseong(D))),
        ('f',           (Choseong(P))),
        ('g',           (Choseong(G))),
        ('G',           (Choseong(J))),
        ('h',           (Choseong(H))),
        ('H',           (Choseong(H))),
        ('k,',          (Jongseong(G))),
        ('k',           (Choseong(K))),
        ('^l',          (Choseong(L))),
        ('{,}l',        (Choseong(L))),
        ('l,',          (Jongseong(L))),
        ('l',           (Jongseong(L), Choseong(L))),
        ('m,',          (Jongseong(M))),
        ('m',           (Choseong(M))),
        ('n,',          (Jongseong(N))),
        ('n',           (Choseong(N))),
        ('p,',          (Jongseong(B))),
        ('p',           (Choseong(P))),
        ('r',           (Choseong(L))),
        ('s',           (Choseong(S))),
        ('t,',          (Jongseong(S))),
        ('t',           (Choseong(T))),
        ('v',           (Choseong(B))),
        ('z',           (Choseong(J))),
        ('%',           (Choseong(NG))),
        ('Ya',          (Jungseong(YA))),
        ('Ye',          (Jungseong(YE))),
        ('Yi',          (Jungseong(I))),
        ('Yo',          (Jungseong(YO))),
        ('Yu',          (Jungseong(YU))),
        ('Ua',          (Jungseong(WA))),
        ('Ue',          (Jungseong(WE))),
        ('Ui',          (Jungseong(WI))),
        ('Uo',          (Jungseong(WEO))),
        ('Uu',          (Jungseong(U))),
        ('a',           (Jungseong(A))),
        ('e',           (Jungseong(E))),
        ('i',           (Jungseong(I))),
        ('o',           (Jungseong(O))),
        ('u',           (Jungseong(U))),
        ('U',           (Jungseong(U))),
    ])

    def normalize(self, string):
        return normalize_roman(string, {
            u'Ĉ': u'ĉ', u'Ĝ': u'ĝ', u'Ĥ': u'ĥ', u'Ĵ': u'ĵ', u'Ŝ': u'ŝ',
            u'Ŭ': u'ŭ'
        })


__lang__ = Esperanto
