# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class AncientGreek(Language):
    """For transcribing Ancient Greek."""

    __iso639__ = {2: 'grc', 3: 'grc'}
    __tmp__ = ',;'

    vowels = u'αάεέηήιίϊοόυύϋωώΥ'
    sv = u'αεηιουω'
    av = u'άέήίόύώ'
    cs = u'βγδζθκλμνξπρστφχψΝΤΞ'
    ob = u'βγδζθκξπστφχψΤΞ'
    notation = Notation([
        (u'(<sv>)\u0300', u'(<av>)'),
        (u'\u0300', None),
        (u'(<sv>)\u0301', u'(<av>)'),
        (u'\u0301', None),
        (u'(<sv>)\u0342', u'(<av>)'),
        (u'\u0342', None),
        (u'\u0344', u'\u0308'),
        (u'ι\u0308', u'ϊ'),
        (u'ί\u0308', u'ϊ'),
        (u'υ\u0308', u'ϋ'),
        (u'ύ\u0308', u'ϋ'),
        (u'\u0304', None),
        (u'\u0313', None),
        (u'\u0343', None),
        (u'\u0314', u'Ξ'),
        (u'\u1FDD', u'Ξ'),
        (u'\u1FDE', u'Ξ'),
        (u'\u1FDF', u'Ξ'),
        (u'\u1FFE', u'Ξ'),
        (u'ἁ', u'Ξα'),
        (u'ἅ', u'Ξά'),
        (u'ἑ', u'Ξε'),
        (u'ἕ', u'Ξέ'),
        (u'ἡ', u'Ξη'),
        (u'ἥ', u'Ξή'),
        (u'ἱ', u'Ξι'),
        (u'ἵ', u'Ξί'),
        (u'ὁ', u'Ξο'),
        (u'ὅ', u'Ξό'),
        (u'ὑ', u'Ξυ'),
        (u'ὕ', u'Ξύ'),
        (u'ὡ', u'Ξω'),
        (u'ὥ', u'Ξώ'),
        (u'αΞ', u'Ξα'),
        (u'άΞ', u'Ξά'),
        (u'εΞ', u'Ξε'),
        (u'έΞ', u'Ξέ'),
        (u'ηΞ', u'Ξη'),
        (u'ήΞ', u'Ξή'),
        (u'ιΞ', u'Ξι'),
        (u'ίΞ', u'Ξί'),
        (u'οΞ', u'Ξο'),
        (u'όΞ', u'Ξό'),
        (u'υΞ', u'Ξυ'),
        (u'ύΞ', u'Ξύ'),
        (u'ωΞ', u'Ξω'),
        (u'ώΞ', u'Ξώ'),
        (u'^υ', u'Ξυ'),
        (u'^ύ', u'Ξύ'),
        (u'ου', u'Υ'),
        (u'{@}υ', u'Υ'),
        (u'υι', u'ι'),
        (u'η', u'ε'),
        (u'ού', u'Υ'),
        (u'{@}ύ', u'Υ'),
        (u'υί', u'ι'),
        (u'υ', u'ι'),
        (u'ά', u'α'),
        (u'έ', u'ε'),
        (u'ή', u'ε'),
        (u'ί', u'ι'),
        (u'ό', u'ο'),
        (u'ύ', u'ι'),
        (u'ω', u'ο'),
        (u'ώ', u'ο'),
        (u'ϊ', u'ι'),
        (u'ϋ', u'ι'),
        (u'ξ', u'κσ'),
        (u'ψ', u'πσ'),
        (u'{@}γ{γ|κ|χ}', u'Ν'),
        (u'{@}ν{γ|κ|χ}', u'Ν'),
        (u'τζ', u'ζ'),
        (u'τσ', u'Τ'),
        (u'ββ', u'β'),
        (u'γγ', u'γ'),
        (u'δδ', u'δ'),
        (u'ζζ', u'ζ'),
        (u'θθ', u'θ'),
        (u'κκ', u'κ'),
        (u'κχ', u'χ'),
        (u'λλ', u'λ'),
        (u'μμ', u'μ'),
        (u'νν', u'ν'),
        (u'ππ', u'π'),
        (u'πφ', u'φ'),
        (u'ρρ', u'ρ'),
        (u'σσ', u'σ'),
        (u'ττ', u'τ'),
        (u'τθ', u'θ'),
        (u'φφ', u'φ'),
        (u'χχ', u'χ'),
        (u'^κ', u'κ;'),
        (u'{<cs>}κ', u'κ;'),
        (u'κ{<ob>}', u'κ,'),
        (u'^π', u'π;'),
        (u'{<cs>}π', u'π;'),
        (u'π{<ob>}', u'π,'),
        (u';', None),
        (u'^λ', u'λ;'),
        (u'^μ', u'μ;'),
        (u'^ν', u'ν;'),
        (u'λ$', u'λ,'),
        (u'μ$', u'μ,'),
        (u'ν$', u'ν,'),
        (u'λ{@|μ,|ν,}', u'λ;'),
        (u'μ{@}', u'μ;'),
        (u'ν{@}', u'ν;'),
        (u'λ', u'λ,'),
        (u'μ', u'μ,'),
        (u'ν', u'ν,'),
        (u'Ν', u'Ν,'),
        (u',,', u','),
        (u',;', None),
        (u',λ,', u'λ,'),
        (u',μ,', u'μ,'),
        (u',ν,', u'ν,'),
        (u'λ{μ;|ν;}', u'λ,'),
        (u';', None),
        (u'β', Choseong(B)),
        (u'γ', Choseong(G)),
        (u'δ', Choseong(D)),
        (u'ζ', Choseong(J)),
        (u'θ', Choseong(T)),
        (u'κ,', Jongseong(G)),
        (u'κ', Choseong(K)),
        (u'^λ', Choseong(L)),
        (u'{,}λ', Choseong(L)),
        (u'λ,', Jongseong(L)),
        (u'λ', Jongseong(L), Choseong(L)),
        (u'μ,', Jongseong(M)),
        (u'μ', Choseong(M)),
        (u'ν,', Jongseong(N)),
        (u'ν', Choseong(N)),
        (u'Ν', Jongseong(NG)),
        (u'π,', Jongseong(B)),
        (u'π', Choseong(P)),
        (u'ρ', Choseong(L)),
        (u'σ', Choseong(S)),
        (u'τ', Choseong(T)),
        (u'Τ', Choseong(C)),
        (u'φ', Choseong(P)),
        (u'χ', Choseong(K)),
        (u'Ξ', Choseong(H)),
        (u'α', Jungseong(A)),
        (u'ε', Jungseong(E)),
        (u'ι', Jungseong(I)),
        (u'ο', Jungseong(O)),
        (u'Υ', Jungseong(U)),
    ])

    def normalize(self, string):
        return normalize_roman(string, {
            u'Α': u'α', u'Ἀ': u'α', u'ᾼ': u'α', u'ᾈ': u'α', u'ἀ': u'α',
            u'ᾳ': u'α', u'ᾀ': u'α', u'Ᾱ': u'α', u'Ᾰ': u'α', u'ᾱ': u'α',
            u'ᾰ': u'α', u'Ά': u'ά', u'Ὰ': u'ά', u'Ἄ': u'ά', u'Ἂ': u'ά',
            u'Ἆ': u'ά', u'ᾌ': u'ά', u'ᾊ': u'ά', u'ᾎ': u'ά', u'ὰ': u'ά',
            u'ᾶ': u'ά', u'ἄ': u'ά', u'ἂ': u'ά', u'ἆ': u'ά', u'ᾴ': u'ά',
            u'ᾲ': u'ά', u'ᾷ': u'ά', u'ᾄ': u'ά', u'ᾂ': u'ά', u'ᾆ': u'ά',
            u'Ἁ': u'ἁ', u'ᾉ': u'ἁ', u'ᾁ': u'ἁ', u'Ἅ': u'ἅ', u'Ἃ': u'ἅ',
            u'Ἇ': u'ἅ', u'ᾍ': u'ἅ', u'ᾋ': u'ἅ', u'ᾏ': u'ἅ', u'ἃ': u'ἅ',
            u'ἇ': u'ἅ', u'ᾅ': u'ἅ', u'ᾃ': u'ἅ', u'ᾇ': u'ἅ', u'Β': u'β',
            u'Γ': u'γ', u'Δ': u'δ', u'Ε': u'ε', u'Ἐ': u'ε', u'ἐ': u'ε',
            u'Έ': u'έ', u'Ὲ': u'έ', u'Ἔ': u'έ', u'Ἒ': u'έ', u'έ': u'έ',
            u'ὲ': u'έ', u'ἔ': u'έ', u'ἒ': u'έ', u'Ἑ': u'ἑ', u'Ἕ': u'ἕ',
            u'Ἓ': u'ἕ', u'ἓ': u'ἕ', u'Ζ': u'ζ', u'Η': u'η', u'Ἠ': u'η',
            u'ῌ': u'η', u'ᾘ': u'η', u'ἠ': u'η', u'ῃ': u'η', u'ᾐ': u'η',
            u'Ή': u'ή', u'Ὴ': u'ή', u'Ἤ': u'ή', u'Ἢ': u'ή', u'Ἦ': u'ή',
            u'ᾜ': u'ή', u'ᾚ': u'ή', u'ᾞ': u'ή', u'ὴ': u'ή', u'ῆ': u'ή',
            u'ἤ': u'ή', u'ἢ': u'ή', u'ἦ': u'ή', u'ῄ': u'ή', u'ῂ': u'ή',
            u'ῇ': u'ή', u'ᾔ': u'ή', u'ᾒ': u'ή', u'ᾖ': u'ή', u'Ἡ': u'ἡ',
            u'ᾙ': u'ἡ', u'ᾑ': u'ἡ', u'Ἥ': u'ἥ', u'Ἣ': u'ἥ', u'Ἧ': u'ἥ',
            u'ᾝ': u'ἥ', u'ᾛ': u'ἥ', u'ᾟ': u'ἥ', u'ἣ': u'ἥ', u'ἧ': u'ἥ',
            u'ᾕ': u'ἥ', u'ᾓ': u'ἥ', u'ᾗ': u'ἥ', u'Θ': u'θ', u'Ι': u'ι',
            u'Ἰ': u'ι', u'ἰ': u'ι', u'Ῑ': u'ι', u'Ῐ': u'ι', u'ῑ': u'ι',
            u'ῐ': u'ι', u'Ί': u'ί', u'Ὶ': u'ί', u'Ἴ': u'ί', u'Ἲ': u'ί',
            u'Ἶ': u'ί', u'ὶ': u'ί', u'ῖ': u'ί', u'ἴ': u'ί', u'ἲ': u'ί',
            u'ἶ': u'ί', u'Ἱ': u'ἱ', u'Ἵ': u'ἵ', u'Ἳ': u'ἵ', u'Ἷ': u'ἵ',
            u'ἳ': u'ἵ', u'ἷ': u'ἵ', u'Ϊ': u'ϊ', u'ΐ': u'ϊ', u'ῒ': u'ϊ',
            u'ῗ': u'ϊ', u'Κ': u'κ', u'Λ': u'λ', u'Μ': u'μ', u'Ν': u'ν',
            u'Ξ': u'ξ', u'Ο': u'ο', u'Ὀ': u'ο', u'ὀ': u'ο', u'Ό': u'ό',
            u'Ὸ': u'ό', u'Ὄ': u'ό', u'Ὂ': u'ό', u'ὸ': u'ό', u'ὄ': u'ό',
            u'ὂ': u'ό', u'Ὁ': u'ὁ', u'Ὅ': u'ὅ', u'Ὃ': u'ὅ', u'ὃ': u'ὅ',
            u'Π': u'π', u'Ρ': u'ρ', u'Ῥ': u'ρ', u'ῤ': u'ρ', u'ῥ': u'ρ',
            u'Σ': u'σ', u'ς': u'σ', u'Τ': u'τ', u'Υ': u'υ', u'ὐ': u'υ',
            u'Ῡ': u'υ', u'Ῠ': u'υ', u'ῡ': u'υ', u'ῠ': u'υ', u'Ύ': u'ύ',
            u'Ὺ': u'ύ', u'ὺ': u'ύ', u'ῦ': u'ύ', u'ὔ': u'ύ', u'ὒ': u'ύ',
            u'ὖ': u'ύ', u'Ὑ': u'ὑ', u'Ὕ': u'ὕ', u'Ὓ': u'ὕ', u'Ὗ': u'ὕ',
            u'ὓ': u'ὕ', u'ὗ': u'ὕ', u'Ϋ': u'ϋ', u'ΰ': u'ϋ', u'ῢ': u'ϋ',
            u'ῧ': u'ϋ', u'Φ': u'φ', u'Χ': u'χ', u'Ψ': u'ψ', u'Ω': u'ω',
            u'Ὠ': u'ω', u'ῼ': u'ω', u'ᾨ': u'ω', u'ὠ': u'ω', u'ῳ': u'ω',
            u'ᾠ': u'ω', u'Ώ': u'ώ', u'Ὼ': u'ώ', u'Ὤ': u'ώ', u'Ὢ': u'ώ',
            u'Ὦ': u'ώ', u'ᾬ': u'ώ', u'ᾪ': u'ώ', u'ᾮ': u'ώ', u'ὼ': u'ώ',
            u'ῶ': u'ώ', u'ὤ': u'ώ', u'ὢ': u'ώ', u'ὦ': u'ώ', u'ῴ': u'ώ',
            u'ῲ': u'ώ', u'ῷ': u'ώ', u'ᾤ': u'ώ', u'ᾢ': u'ώ', u'ᾦ': u'ώ',
            u'Ὡ': u'ὡ', u'ᾩ': u'ὡ', u'ᾡ': u'ὡ', u'Ὥ': u'ὥ', u'Ὣ': u'ὥ',
            u'Ὧ': u'ὥ', u'ᾭ': u'ὥ', u'ᾫ': u'ὥ', u'ᾯ': u'ὥ', u'ὣ': u'ὥ',
            u'ὧ': u'ὥ', u'ᾥ': u'ὥ', u'ᾣ': u'ὥ', u'ᾧ': u'ὥ'
        })


__lang__ = AncientGreek
