# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class Dutch(Language):
    """For transcribing Dutch."""

    __iso639__ = {1: 'nl', 2: 'dut', 3: 'nld'}
    __tmp__ = '%,;&'

    vowels = 'aeEioOuUyQ'
    cs = 'b', 'B', 'c', 'C', 'd', 'D', 'f', 'F', 'g', 'G', 'h', 'j', 'J', \
         'k', 'K', 'l', 'm', 'n', 'N', 'p', 'P', 'q', 'r', 's', 't', 'T', \
         'v', 'w', 'x', 'X', 'z', '%' # consonants
    son = 'lmnNrw' # sonorants
    short = 'aeEiouU' # short vowels
    notation = Notation([
        (u'’', '\''),
        (' aan ', '/aan/'),
        ('^aan ', 'aan/'),
        (' bij ', '/bij/'),
        ('^bij ', 'bij/'),
        (' boven ', '/boven/'),
        ('^boven ', 'boven/'),
        (' en ', '/en/'),
        ('^en ', 'en/'),
        (' in ', '/in/'),
        ('^in ', 'in/'),
        (' op ', '/op/'),
        ('^op ', 'op/'),
        (' over ', '/over/'),
        ('^over ', 'over/'),
        (' of ', '/of/'),
        ('^de ', 'de/'),
        ('^den ', 'den/'),
        ('^der ', 'der/'),
        ('^des ', 'des/'),
        ('^di ', 'di/'),
        ('^het ', 'het/'),
        ('^onder ', 'onder/'),
        ('^sint ', 'sint/'),
        ('^te ', 'te/'),
        ('^ten ', 'ten/'),
        ('^ter ', 'ter/'),
        ('^thoe ', 'thoe/'),
        ('^tot ', 'tot/'),
        ('^uit ', 'uit/'),
        ('^uijt ', 'uijt/'),
        ('^van ', 'van/'),
        ('^ver ', 'ver/'),
        ('^voor ', 'voor/'),
        ('-', '/'),
        ('^\'s ', 's/'),
        ('^\'t ', 'Qt,/'),
        ('^\'t', 'Qt,'),
        ('hoek van/holland', 'hoek/van/holland'),
        ('hof van/twente', 'hof/van/twente'),
        ('ronde venen', 'ronde/venen'),
        ('^midden ', 'midden/'),
        ('^neder ', 'neder/'),
        ('^nieuw ', 'nieuw/'),
        ('^nieuwe ', 'nieuwe/'),
        ('^noord ', 'noord/'),
        ('^oost ', 'oost/'),
        ('^west ', 'west/'),
        ('^zuid ', 'zuid/'),
        (u'aimé', u'emé'),
        (u'curaçao', 'curaso'),
        ('curacao', 'curaso'),
        (u'française', 'frangsEzY'),
        ('francaise', 'frangsEzY'),
        (u'français', 'frangsE'),
        ('francais', 'frangsE'),
        (u'françoise', 'frangsoeazY'),
        ('francoise', 'frangsoeazY'),
        (u'françois', 'frangsoea'),
        ('francois', 'frangsoea'),
        (u'ç', 's'),
        (u'{@}ä{@}', '%a%'),
        (u'{@}ä', '%a'),
        (u'ä{@}', 'a%'),
        (u'ä', 'e'),
        (u'{@}ë{@}', '%e%'),
        (u'{@}ë', '%e'),
        (u'ë{@}', 'e%'),
        (u'ë', 'E'),
        (u'ée', 'ee'),
        (u'é', 'E'),
        (u'{@}ï{@}', '%i%'),
        (u'{@}ï', '%i'),
        (u'ï{@}', 'i%'),
        (u'ï', 'i'),
        (u'{@}ö{@}', '%o%'),
        (u'{@}ö', '%o'),
        (u'ö{@}', 'o%'),
        (u'ö', 'eu'),
        (u'{@}ü{@}', '%u%'),
        (u'{@}ü', '%u'),
        (u'ü{@}', 'u%'),
        (u'ü', 'u'),
        ('^{<cs>}ig', 'igg'),
        ('^{(<cs>)(<cs>)}ig', 'igg'),
        ('^{(<cs>)(<cs>)(<cs>)}ig', 'igg'),
        ('aalbes', 'aalbEs'),
        ('^aang', 'aan-g'),
        ('aapmens', 'aapmEns'),
        ('^abc$', 'abece'),
        ('adelbert', 'adelbErt'),
        ('ademtest', 'ademtEst'),
        ('adres', 'adrEs'),
        ('adrien', 'adriEn'),
        ('advocaat', 'aDvocaat'),
        ('aequo', 'equo'),
        ('aftershave', 'aftQrsjeev'),
        ('afvalrace', 'afvalrees'),
        ('agaath', 'agaat'),
        ('agath', 'agat'),
        ('ageeth', 'ageet'),
        ('ageth', 'aget'),
        ('^aim{e|ee}', 'em'),
        ('allerbest', 'allerbEst'),
        ('altsaxo', 'altYsaxo'),
        ('amanuens', 'amanu%ens'),
        ('amulet', 'amulEt'),
        ('ancien', 'anciEn'),
        ('andelst', 'andElst'),
        ('angina', 'anggina'),
        ('angli{c|st}', 'anggli'),
        ('angol{a|ees}', 'anggol'),
        ('anouk', 'anoek'),
        ('anthon', 'anton'),
        ('apothe{ek|k}', 'apote'),
        ('^apropos$', 'apropo'),
        ('^a propos$', 'apropo'),
        ('aquarel', 'aquarEl'),
        ('archipel', 'archipEl'),
        ('architect', 'architEct'),
        ('arrest', 'arrEst'),
        ('aspect', 'aspEct'),
        ('asbest', 'asbEst'),
        ('autorace', 'autorees'),
        ('baby', 'beeby'),
        ('badge', 'bezi'),
        ('badminton', 'bedminton'),
        ('bagage', 'bagaze'),
        ('bagatel', 'bagatEl'),
        ('bajonet', 'bajonEt'),
        ('^balpen', 'balpEn'),
        ('balth', 'balt'),
        ('banket', 'bankEt'),
        ('bankstel', 'bankstEl'),
        ('baret', 'barEt'),
        ('barkeep', 'barkip'),
        ('barones', 'baronEs'),
        ('barrage', 'barraze'),
        ('barthol', 'bartol'),
        ('baseball', 'beesbol'),
        ('bassin', 'bassEng'),
        ('beautycase', 'bJoetykees'),
        ('bed', 'bEd'),
        ('bEdekt', 'bedEkt'),
        ('beige', 'beize'),
        ('^beken', 'bekEn'),
        ('bekend', 'bekEnd'),
        ('berg', 'bErg'),
        ('besef', 'besEf'),
        ('besmet', 'besmEt'),
        ('beste{k|l|m}', 'bestE'),
        ('bevlek', 'bevlEk'),
        ('bijec', 'bi-jec'),
        ('bijou', 'bizoe'),
        ('biljet', 'biljEt'),
        ('bingo', 'bingGo'),
        ('biscuit', 'biscu%i'),
        ('bordes', 'bordEs'),
        ('bosbes', 'bosbEs'),
        ('boudier', 'boediE'),
        ('boulevard', 'boelevar'),
        ('bourgogne', 'boergonje'),
        ('bourgond', 'boergond'),
        ('bouvier', 'boeviE'),
        ('bowl', 'bol'),
        ('braille', 'braje'),
        ('brek', 'brEk'),
        ('breng', 'brEng'),
        ('budget', 'buzEt'),
        ('buffet', 'buffEt'),
        ('bungalowtent', 'bungalowtEnt'),
        ('bungalow', 'bungGalo'),
        ('cabaretier', 'cabarEtiE'),
        ('cabaret', 'cabarE'),
        ('cabriolet', 'cabriolEt'),
        ('cadet', 'cadEt'),
        ('caissiEre', 'cassiEre'),
        ('cake', 'keek'),
        ('cahier', 'cajE'),
        ('camouflage', 'camoeflaze'),
        ('campagne', 'campanje'),
        ('cantharel', 'cantarEl'),
        ('capuchon', 'capusjon'),
        ('cari%es', 'cariEs'),
        ('carillon', 'cariljon'),
        ('cashew', 'kesjoe'),
        ('cash', 'kesj'),
        ('castagnet', 'castanjet'),
        ('catheter', 'cateter'),
        ('^cees', 'kees'),
        ('chalet', 'sjalE'),
        ('champagne', 'sjampanje'),
        ('champignon', 'sjampinjon'),
        ('chantage', 'sjantaze'),
        ('chante{er|re}', 'sjante'),
        ('chaperon', 'sjaperon'),
        ('charcuterie', 'sjarcuterie'),
        ('charles', 'sjarl'),
        ('^charl', 'sjarl'),
        ('charmant', 'sjarmant'),
        ('chauffeur', 'sjoffeur'),
        ('cheque', 'sjEk'),
        ('cheryl', 'sjeryl'),
        ('chris', 'kris'),
        ('cologne', 'colonje'),
        ('compagn{i|y}', 'compan'),
        ('compagn', 'companj'),
        ('concertza{al|l}', 'concert-za'),
        ('conci%erge', 'conciErze'),
        ('concours', 'concoer'),
        ('concurrent', 'concurrEnt'),
        ('condens', 'condEns'),
        ('conferencier', 'conferangsiE'),
        ('conference', 'conferangs'),
        ('congres', 'conggrEs'),
        ('consequent', 'consequEnt'),
        ('consignatie', 'consinjatie'),
        ('contactlens', 'contactlEns'),
        ('container', 'conteener'),
        ('continue{er|r}', 'continu%e'),
        ('contour', 'contoer'),
        ('copyright', 'copyrajt'),
        ('cornedbeef', 'cornedbif'),
        ('corps', 'cor'),
        ('correct', 'corrEct'),
        ('corrige', 'corrize'),
        ('corsage', 'corsaze'),
        ('coulant', 'coelant'),
        ('coulisse', 'coelisse'),
        ('coup', 'coep'),
        ('courant', 'coerant'),
        ('coureur', 'coereur'),
        ('courgette', 'coerzette'),
        ('courtage', 'coertaze'),
        ('couture', 'coeture'),
        ('couturier', 'coeturiE'),
        ('couveuse', 'coeveuse'),
        ('cowboy', 'cauboy'),
        ('crash', 'crEsj'),
        ('crawl', 'crol'),
        ('crEche', 'crEsj'),
        ('crEme', 'crEm'),
        ('crime', 'crim'),
        ('croissant', 'croeassang'),
        ('croque', 'crok'),
        ('cursusjaar', 'cursusYjaar'),
        ('damhert', 'damhErt'),
        ('daniel', 'daniEl'),
        ('dani%el', 'daniEl'),
        ('dashboard', 'desjbord'),
        ('davidster', 'davit,ster'),
        ('debet', 'debEt'),
        ('decadent', 'decadEnt'),
        ('decibel', 'decibEl'),
        ('defect', 'defEct'),
        ('depot$', 'depo'),
        ('depots', 'depos'),
        ('dessert', 'dessEr'),
        ('dessin', 'dessEng'),
        ('detaillist', 'detajist'),
        ('detail', 'detaj'),
        ('detective', 'ditectiv'),
        ('diligence', 'dilizangce'),
        ('direct', 'dirEct'),
        ('discothe', 'discote'),
        ('discretie', 'discreti'),
        ('display', 'displey'),
        ('divers', 'divErs'),
        ('dividend', 'dividEnd'),
        ('doodstraf', 'dood%straf'),
        ('doodziek', 'dood%ziek'),
        ('doodzonde', 'dood%zonde'),
        ('doroth', 'dorot'),
        ('dossier', 'dossiE'),
        ('douan{e|i}', 'doean'),
        ('doubl', 'doebl'),
        ('douche$', 'doesj'),
        ('douche', 'doesje'),
        ('drenthe', 'drente'),
        ('drinkyoghurt', 'drinkYJoghurt'),
        ('drukpers', 'drukpErs'),
        ('drumstel', 'drumstEl'),
        ('^dumas$', 'duma'),
        ('dyk', 'dijk'),
        ('eerhestel', 'eerhestEl'),
        ('effect', 'effEct'),
        ('eicel', 'eicEl'),
        ('eindhoven', 'einthoven'),
        ('elektricien', 'elektriciEng'),
        ('^eljero', 'elzero'),
        ('employE', 'amploeajE'),
        ('enschede', 'enschedE'),
        ('ernst', 'Ernst'),
        ('erwt', 'Ert'),
        ('esther', 'ester'),
        ('etage', 'etaze'),
        ('etalage', 'etalaze'),
        ('ether', 'eter'),
        ('ethiek', 'etiek'),
        ('ethiop', 'etiop'),
        ('ethisch', 'etisch'),
        ('eugene', 'euzEn'),
        ('eurocent', 'eurocEnt'),
        ('euthanas', 'eutanas'),
        ('evacue{er|r}', 'evacu%e'),
        ('evangel', 'evanggel'),
        ('evengoed', 'even-goed'),
        ('examengeld', 'examen-gEld'),
        ('exces', 'excEs'),
        ('{~@}ex', 'Ex'),
        ('floret', 'florEt'),
        ('foetus', 'feutus'),
        ('forel', 'forEl'),
        ('forfait', 'forfE'),
        ('fokstier', 'fokstir'),
        ('formulier', 'formulir'),
        ('foyer', 'foeajE'),
        ('franchise', 'fransjize'),
        ('frangipane', 'frangzipane'),
        ('freak', 'fri-k'),
        ('freelancer', 'frilangcer'),
        ('freelance', 'frilangs'),
        ('freudia', 'froidia'),
        ('frikadel', 'frikadEl'),
        ('frou-frou', 'froe-froe'),
        ('fulltime', 'foeltajm'),
        ('funest', 'funEst'),
        ('gabriel', 'GabriEl'),
        ('gabri%el', 'GabriEl'),
        ('^game$', 'Geem'),
        ('^games$', 'Geems'),
        ('gameboy', 'Geemboy'),
        ('gebrek', 'gebrEk'),
        ('gelukwens', 'gelukwEns'),
        ('gemenebest', 'gemenebEst'),
        ('gemengd', 'gemEngd'),
        ('gEnant', 'zEnant'),
        ('gendarme', 'zangdarme'),
        ('genEve', 'zenEve'),
        ('genie$', 'zenie'),
        ('genie{%en|tj}', 'zenie'),
        ('genre', 'zangrY'),
        ('^giovan', 'zovan'),
        ('gogh', 'Gogh'),
        ('grens', 'grEns'),
        ('greth{a|e}', 'gret'),
        ('^guido', 'gido'),
        ('^hamel', 'hamEl'),
        ('hef', 'hEf'),
        ('hek', 'hEk'),
        ('hengst', 'hEngst'),
        ('ijssel', 'ijssQl'),
        ('israel', 'israEl'),
        ('isra%el', 'israEl'),
        ('jacques', 'zaak'),
        ('jeanette', 'zaanEt'),
        ('jeanet', 'zaanEt'),
        ('jeanne$', 'zaan'),
        ('jockey', 'zoki'),
        ('johannes', 'johannEs'),
        ('^john$', 'zon'),
        ('jozef', 'jozEf'),
        ('^beken', 'bekEn'),
        ('beken{d|t}', 'bekEn'),
        ('^erken', 'erkEn'),
        ('erken{d|t}', 'erkEn'),
        ('^herken', 'herkEn'),
        ('^ontken', 'ontkEn'),
        ('ontken{d|t}', 'ontkEn'),
        ('^toeken', 'toekEn'),
        ('toeken{d|t}', 'toekEn'),
        ('^verken', 'verkEn'),
        ('klem{d|t}', 'klEm'),
        ('korthal', 'kortal'),
        ('leg{d|t}', 'lEg'),
        ('lingerie', 'lengzerie'),
        ('lingu%ist', 'linggu%ist'),
        ('^louis$', 'loei'),
        ('^louis', 'loeis'),
        ('lyonnet', 'lyonnE'),
        ('manuel', 'manuEl'),
        ('^margot$', 'margo'),
        ('^mari%e', 'mariE'),
        ('marth', 'mart'),
        ('^mary$', 'mery'),
        ('mathild', 'matild'),
        ('melk', 'mElk'),
        ('merk', 'mErk'),
        ('michael', 'mikaEl'),
        ('micha%el', 'mikaEl'),
        ('^michel$', 'misjEl'),
        ('michi%el', 'mikiEl'),
        ('model', 'modEl'),
        ('monsieur', 'mQsieu'),
        ('nerf', 'nErf'),
        ('^nigel', 'naizel'),
        ('^no%e', 'noE'),
        ('ongerust', 'onggerust'),
        ('orkest', 'orkEst'),
        ('pech', 'pEch'),
        ('persoonsbed', 'persoonsbEd'),
        ('pierre', 'piEr'),
        ('pincher', 'pinsjer'),
        ('posthum', 'postum'),
        ('rafael', 'rafaEl'),
        ('rafa%el', 'rafaEl'),
        ('recept', 'recEpt'),
        ('reinier', 'reini%er'),
        ('rhijn', 'rijn'),
        ('richard', 'rikard'),
        ('rogier', 'rogi%er'),
        ('ryan', 'raien'),
        ('scherm', 'schErm'),
        ('sharon', 'sjaron'),
        ('spel', 'spEl'),
        ('spionage', 'spionaze'),
        ('streng', 'strEng'),
        ('student', 'studEnt'),
        ('term', 'tErm'),
        ('the{a|o}', 'te'),
        ('thierry', 'tiErry'),
        ('thijs', 'tijs'),
        ('thys', 'tys'),
        ('timoth', 'timot'),
        ('toilette', 'toealEt'),
        ('toilet', 'toealEt'),
        ('tref', 'trEf'),
        ('trek', 'trEk'),
        ('van/Gogh', 'wan/Gogh'),
        ('vel{d|t}', 'vEl'),
        ('vEldhoven', 'vEld/hoven'),
        ('^vera$', 'wera'),
        ('veroni', 'weroni'),
        ('victor', 'wictor'),
        ('vincent', 'wincEnt'),
        ('viol', 'wiol'),
        ('vlek', 'vlEk'),
        ('weg', 'wEg'),
        ('wenst', 'wEnst'),
        ('^wens', 'wEns'),
        ('werk', 'wErk'),
        ('wesley', 'wesly'),
        ('wet', 'wEt'),
        ('^wt', 'uwt'),
        ('zet', 'zEt'),
        ('szoon', 's/zoon'),
        ('echt', 'Echt'),
        ('egd', 'Egd'),
        ('ent', 'Ent'),
        ('eau', 'o'), # common French spellings
        ('%e{l|ls|t|ts|tt|tts}$', 'E'),
        ('air', 'Er'),
        ('oir$', 'oear'),
        ('^ti', 'tiF'),
        ('tie{f|k}', 'ti'),
        ('tie$', 'sie'),
        ('tieus', 'sieus'),
        ('{n|r}tie$', 'sie'),
        ('ti{eel|%el}', 'si'),
        ('ti{aal|al}', 'si'),
        ('tion$', 'sjon'),
        ('tion{eel|%el}', 'sjon'),
        ('tione{er|r}', 'sjone'),
        ('tion{ne|s}', 'sjon'),
        ('tium', 'sium'),
        ('F', None),
        ('{<cs>}ig$', 'Qg'),
        ('{<cs>}igd$', 'Qgd'),
        ('{<cs>}igde$', 'Qgde'),
        ('{<cs>}ige$', 'Qge'),
        ('{<cs>}igen$', 'Qgen'),
        ('{<cs>}igheid$', 'Qgheid'),
        ('{<cs>}iging$', 'Qging'),
        ('^over', 'ovQr'),
        ('sch{@}', 'sX'),
        ('sch', 's'),
        ('ch', 'X'),
        ('c{e|E|i|y}', 's'),
        ('c', 'k'),
        ('qq', 'q'),
        ('qu', 'kw'),
        ('q', 'k'),
        ('x', 'ks'),
        ('ng', 'N'),
        ('nk', 'Nk'),
        ('dt$', 't'),
        ('dt{<cs>}', 't'),
        ('gh', 'g'),
        ('ph', 'p'),
        ('^th', 't'),
        ('^kh', 'k'),
        ('h{<cs>}', None),
        ('h$', None),
        ('sj{@}', 'sJ'),
        ('sj', 'si'),
        ('sz$', 's'),
        ('sz{<cs>}', 's'),
        ('ts', 'C'),
        ('tz', 'C'),
        ('^v', 'f'),
        ('uw', 'uW'),
        ('v$', 'f'),
        ('^y{@}', 'j'),
        ('y', 'i%'),
        ('z$', 's'),
        ('bb', 'b'),
        ('dd', 'd'),
        ('ff', 'f'),
        ('fv', 'f'),
        ('gg', 'g'),
        ('hh', 'h'),
        ('kk', 'k'),
        ('ll', 'l'),
        ('mm', 'm'),
        ('nn', 'n'),
        ('pp', 'p'),
        ('rr', 'r'),
        ('ss', 's'),
        ('tt', 't'),
        ('mbt', 'mt'),
        ('mpt', 'mt'),
        ('b$', '-p'),
        ('d$', '-t'),
        ('ds{~@}', 'C'),
        ('ds$', 'C'),
        ('dz{~@}', 'C'),
        ('dz$', 'C'),
        ('^ie{<cs>}', 'i'),
        ('{<cs>}ie{<cs>}', 'i'),
        ('^oe{<cs>}', 'U'),
        ('{<cs>}oe{<cs>}', 'U'),
        ('b{@|<son>|j}', 'B'),
        ('{<son>}b', 'B'),
        ('^{(<short>)}b{<cs>}', 'P'),
        ('{(<cs>)(<short>)}b{<cs>}', 'P'),
        ('B', 'b'),
        ('d{@|<son>|j}', 'D'),
        ('{<son>}d', 'D'),
        ('^{(<short>)}d{<cs>}', 'T'),
        ('{(<cs>)(<short>)}d{<cs>}', 'T'),
        ('D', 'd'),
        ('p{@|<son>|j}', 'F'),
        ('{<son>}p', 'F'),
        ('^{(<short>)}p{<cs>}', 'P'),
        ('{(<cs>)(<short>)}p{<cs>}', 'P'),
        ('^{(<short>)}p$', 'P'),
        ('{(<cs>)(<short>)}p$', 'P'),
        ('F', 'p'),
        ('t{@|<son>|j}', 'F'),
        ('{<son>}t', 'F'),
        ('^{(<short)>}t{<cs>}', 'T'),
        ('{(<cs>)(<short>)}t{<cs>}', 'T'),
        ('^{(<short>)}t$', 'T'),
        ('{(<cs>)(<short>)}t$', 'T'),
        ('F', 't'),
        ('k{@|<son>|j|v}', 'F'),
        ('{<son>}k', 'F'),
        ('^{(<short>)}k{<cs>}', 'K'),
        ('{(<cs>)(<short>)}k{<cs>}', 'K'),
        ('^{(<short>)}k$', 'K'),
        ('{(<cs>)(<short>)}k$', 'K'),
        ('F', 'k'),
        ('{~@}bj', 'bi%'),
        ('^bj', 'bi%'),
        ('{~@}dj', 'di%'),
        ('^dj', 'di%'),
        ('{~@}pj', 'pi%'),
        ('^pj', 'pi%'),
        ('{~@}tj', 'ti%'),
        ('^tj', 'ti%'),
        ('{~@}kj', 'ki%'),
        ('^kj', 'ki%'),
        ('{~@}rj', 'ri%'),
        ('^rj', 'ri%'),
        ('{b|d|p|t|k|r}j', 'Yj'),
        ('{@}ie', 'i%e'),
        ('w', 'v'),
        ('ae', 'aa'),
        ('aa', 'a'),
        ('auW', 'aU%'),
        ('au', 'aU%'),
        ('ouW', 'aU%'),
        ('ou', 'aU%'),
        ('{@}iji', 'i'),
        ('{@}ij{@}', 'i%j'),
        ('{@}ij', 'i%'),
        ('ij', 'ei'),
        ('eeuW', 'eiU%'),
        ('ieuW', 'iU%'),
        ('euW', 'e-u%'),
        ('iee', 'i%ee'),
        ('ee', 'ei'),
        ('oo', 'o'),
        ('ui', 'au%'),
        ('uy', 'au%'),
        ('eu', 'O%'),
        ('uee', 'u%ee'),
        ('ue', 'uu'),
        ('uW', 'uu%'),
        ('uu', 'u'),
        ('i%i', 'i'),
        ('ie', 'i'),
        ('ii', 'i'),
        ('oe', 'U'),
        ('-', None),
        ('e$', 'Q'),
        ('^e{(<cs>)}$', 'E'),
        ('^{(<cs>)}e{(<cs>)}$', 'E'),
        ('^{(<cs>)(<cs>)}e{(<cs>)}$', 'E'),
        ('^{(<cs>)(<cs>)(<cs>)}e{(<cs>)}$', 'E'),
        ('^e{(<cs>)(<cs>)}$', 'E'),
        ('^{(<cs>)}e{(<cs>)(<cs>)}$', 'E'),
        ('^{(<cs>)(<cs>)}e{(<cs>)(<cs>)}$', 'E'),
        ('^{(<cs>)(<cs>)(<cs>)}e{(<cs>)(<cs>)}$', 'E'),
        ('^e{(<cs>)(<cs>)(<cs>)}$', 'E'),
        ('^{(<cs>)}e{(<cs>)(<cs>)(<cs>)}$', 'E'),
        ('^{(<cs>)(<cs>)}e{(<cs>)(<cs>)(<cs>)}$', 'E'),
        ('^{(<cs>)(<cs>)(<cs>)}e{(<cs>)(<cs>)(<cs>)}$', 'E'),
        ('^e{(<cs>)(<cs>)(<cs>)(<cs>)}$', 'E'),
        ('^{(<cs>)}e{(<cs>)(<cs>)(<cs>)(<cs>)}$', 'E'),
        ('^{(<cs>)(<cs>)}e{(<cs>)(<cs>)(<cs>)(<cs>)}$', 'E'),
        ('^{(<cs>)(<cs>)(<cs>)}e{(<cs>)(<cs>)(<cs>)(<cs>)}$', 'E'),
        ('{<cs>}e{(<cs>)}$', 'Q'),
        ('{<cs>}e{(<cs>)(<cs>)}$', 'Q'),
        ('{<cs>}e{(<cs>)(<cs>)(<cs>)}$', 'Q'),
        ('{<cs>}e{(<cs>)(<cs>)(<cs>)(<cs>)}$', 'Q'),
        ('E', 'e'),
        ('P', 'p,'),
        ('T', 't,'),
        ('K', 'k,'),
        ('j{@}', 'J'),
        ('j', 'i'),
        ('{C|z}J', None),
        ('^l', 'l;'),
        ('^m', 'm;'),
        ('^n', 'n;'),
        ('l$', 'l,'),
        ('m$', 'm,'),
        ('n$', 'n,'),
        ('l{@|m,|n,|N}', 'l;'),
        ('{,}l', 'l;'),
        ('m{@}', 'm;'),
        ('n{@}', 'n;'),
        ('l', 'l,'),
        ('m', 'm,'),
        ('n', 'n,'),
        ('N', 'N,'),
        (',,', ','),
        (',;', None),
        (',l,', 'l,'),
        (',m,', 'm,'),
        (',n,', 'n,'),
        (',N,', 'N,'),
        ('l{m;|n;}', 'l,'),
        (';', None),
        ('^a', '&a'),
        ('^e', '&e'),
        ('^i', '&i'),
        ('^o', '&o'),
        ('^O', '&O'),
        ('^u', '&u'),
        ('^U', '&U'),
        ('^Q', '&Q'),
        ('^J', '&J'),
        ('b', Choseong(B)),
        ('C', Choseong(C)),
        ('d', Choseong(D)),
        ('f', Choseong(P)),
        ('g', Choseong(H)),
        ('G', Choseong(G)),
        ('h', Choseong(H)),
        ('k,', Jongseong(G)),
        ('k', Choseong(K)),
        ('^l', Choseong(L)),
        ('{,}l', Choseong(L)),
        ('l,', Jongseong(L)),
        ('l', Jongseong(L), Choseong(L)),
        ('m,', Jongseong(M)),
        ('m', Choseong(M)),
        ('n,', Jongseong(N)),
        ('n', Choseong(N)),
        ('N', Jongseong(NG)),
        ('p,', Jongseong(B)),
        ('p', Choseong(P)),
        ('r', Choseong(L)),
        ('s', Choseong(S)),
        ('t,', Jongseong(S)),
        ('t', Choseong(T)),
        ('v', Choseong(B)),
        ('X', Choseong(H)),
        ('z', Choseong(J)),
        ('&', Choseong(NG)),
        ('Ja', Jungseong(YA)),
        ('Je', Jungseong(YE)),
        ('Ji', Jungseong(I)),
        ('Jo', Jungseong(YO)),
        ('JO', Jungseong(YE)),
        ('Ju', Jungseong(YU)),
        ('JU', Jungseong(YU)),
        ('JQ', Jungseong(YEO)),
        ('a', Jungseong(A)),
        ('e', Jungseong(E)),
        ('i', Jungseong(I)),
        ('o', Jungseong(O)),
        ('O', Jungseong(OE)),
        ('u', Jungseong(WI)),
        ('U', Jungseong(U)),
        ('Q', Jungseong(EO)),
        ('Y', Jungseong(EU)),
    ])

    def normalize(self, string):
        return normalize_roman(string, {
            u'Ä': u'ä', u'Ç': u'ç', u'Ë': u'ë', u'É': u'é', u'È': u'é',
            u'è': u'é', u'Ê': u'é', u'ê': u'é', u'Ï': u'ï', u'Ḯ': u'ï',
            u'Ḯ': u'ï', u'Ö': u'ö', u'Ĳ': u'ij', u'ĳ': u'ij', u'Ü': u'ü',
            u'Ÿ': u'ij', u'ÿ': u'ij'
        })


__lang__ = Dutch
