# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class Polish(Language):
    """For transcribing Polish."""

    __iso639__ = {1: 'pl', 2: 'pol', 3: 'pol'}
    __tmp__ = '%,;'

    vowels = 'aeiouy'
    cs = 'bcCdfghjklmnpqrstvwxz'
    vl = 'cCfhkpst'
    notation = Notation([
        (u'wałęsa',       u'wałensa'),
        (u'ą{l|ł}',       'o'),
        (u'ą',            'oN'),
        (u'ę{l|ł}',       'e'),
        (u'ę$',           'e'),
        (u'ę',            'eN'),
        (u'ół',           'u'),
        (u'łł',           u'ł'),
        (u'ł{@}',         'W'),
        (u'ł',            '%u'),
        (u'ó',            'u'),
        ('rz',            u'ż'),
        (u'dź',           u'ć'),
        (u'ć',            'cj'),
        ('^th',           't'),
        ('hh',            'h'),
        ('ch',            'h'),
        (u'ź{<vl>}',      'sj'),
        (u'ź$',           'sj'),
        (u'ź',            'zj'),
        (u'ś',            'sj'),
        ('dz{<vl>}',      'c'),
        ('dz$',           'c'),
        ('dz',            'z'),
        (u'dż{@}',        'z'),
        (u'dż',           'C'),
        ('cz',            'C'),
        ('cj',            'C'),
        (u'C$',           'ci'),
        ('C{@}',          'c'),
        ('C',             'ci'),
        ('b{<vl>}',       'p'),
        ('b$',            'p'),
        ('d{<vl>}',       't'),
        ('d$',            't'),
        ('g{<vl>}',       'k'),
        ('g$',            'k'),
        ('w{<vl>}',       'f'),
        ('w$',            'f'),
        (u'ż{<vl>}',      'sz'),
        (u'{<vl>}ż',      'sz'),
        (u'ż$',           'sz'),
        (u'ż{@}',         'z'),
        (u'żj',           'zj'),
        (u'ż',            'zu'),
        ('sz{@}',         'sJ'),
        ('szj',           'sJ'),
        ('sz$',           'si'),
        ('sz',            'sJu'),
        ('z{<vl>}',       's'),
        ('z$',            's'),
        ('xx',            'x'),
        ('x',             'ks'),
        ('tt',            't'),
        ('w',             'v'),
        ('q',             'kv'),
        ('aa',            'a'),
        ('bb',            'b'),
        ('dd',            'd'),
        ('ee',            'e'),
        ('ff',            'f'),
        ('jj',            'ij'),
        ('ii',            'i'),
        ('zj{@}',         'z'),
        ('{<cs>}je',      'e'),
        ('j{@}',          'J'),
        ('j',             'i'),
        ('ij',            'i'),
        ('yj',            'y'),
        ('kk',            'k'),
        ('ll',            'l'),
        ('{@}mm{@}',      'm,m'),
        ('mm',            'm'),
        ('{@}nn{@}',      'n,n'),
        ('oo',            'o'),
        ('pp',            'p'),
        ('rr',            'r'),
        ('ss',            's'),
        ('tt',            't'),
        ('uu',            'u'),
        ('X',             None),
        ('vv',            'v'),
        ('^y{@}',         'J'),
        ('yy',            'y'),
        ('y',             'i'),
        ('zz',            'z'),
        ('{@}k{p|s|t|z}', 'k,'),
        ('{@}p{k|s|t|z}', 'p,'),
        ('^l',            'l;'),
        ('^m',            'm;'),
        ('^n',            'n;'),
        ('l$',            'l,'),
        ('m$',            'm,'),
        ('n$',            'n,'),
        ('l{@|J|m,|n,}',  'l;'),
        ('{,}l',          'l;'),
        ('m{@|J}',        'm;'),
        ('n{@|J}',        'n;'),
        ('l',             'l,'),
        ('m',             'm,'),
        ('n',             'n,'),
        (',,',            ','),
        (',;',            None),
        (',l,',           'l,'),
        (',m,',           'm,'),
        (',n,',           'n,'),
        ('l{m;|n;}',      'l,'),
        (';',             None),       
        ('b',             Choseong(B)),
        ('c',             Choseong(C)),
        ('d',             Choseong(D)),
        ('f',             Choseong(P)),
        ('g',             Choseong(G)),
        ('h',             Choseong(H)),
        ('k,',            Jongseong(G)),
        ('k',             Choseong(K)),
        ('^l',            Choseong(L)),
        ('{,}l',          Choseong(L)),
        ('l,',            Jongseong(L)),
        ('l',             Jongseong(L), Choseong(L)),
        ('m,',            Jongseong(M)),
        ('m',             Choseong(M)),
        ('n,',            Jongseong(N)),
        ('n',             Choseong(N)),
        ('N',             Jongseong(NG)),
        ('p,',            Jongseong(B)),
        ('p',             Choseong(P)),
        ('r',             Choseong(L)),
        ('s',             Choseong(S)),
        ('t',             Choseong(T)),
        ('v',             Choseong(B)),
        ('z',             Choseong(J)),
        ('Ja',            Jungseong(YA)),
        ('Je',            Jungseong(YE)),
        ('Ji',            Jungseong(I)),
        ('Jo',            Jungseong(YO)),
        ('Ju',            Jungseong(YU)),
        ('Wa',            Choseong(NG), Jungseong(WA)),
        ('We',            Choseong(NG), Jungseong(WE)),
        ('Wi',            Choseong(NG), Jungseong(WI)),
        ('Wo',            Choseong(NG), Jungseong(WEO)),
        ('Wu',            Choseong(NG), Jungseong(U)),
        ('a',             Jungseong(A)),
        ('e',             Jungseong(E)),
        ('i',             Jungseong(I)),
        ('o',             Jungseong(O)),
        ('u',             Jungseong(U)),
    ])

    def normalize(self, string):
        return normalize_roman(string, {
            u'Ą': u'ą', u'Ć': u'ć', u'Ę': u'ę', u'Ł': u'ł', u'Ó': u'ó',
            u'Ś': u'ś', u'Ź': u'ź', u'Ż': u'ż'
        })


__lang__ = Polish
