# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class Romanian(Language):
    """For transcribing Romanian."""

    __iso639__ = {1: 'ro', 2: 'rum', 3: 'ron'}

    vowels = 'aAeiIou'
    voiceless = 'CfhkpstT'
    notation = Notation([
        (u'ă',                'A'),
        (u'â',                'I'),
        (u'î',                'I'),
        (u'ș',                'S'),
        (u'ț',                'T'),
        ('ch',                'k'),
        ('gh',                'G'),
        ('^y{@}',             'Y'),
        ('y',                 'i'),
        ('cea',               'Ca'),
        ('gea',               'ja'),
        ('c{e|i}',            'C'),
        ('g{e|i}',            'j'),
        ('cc',                'c'),
        ('gg',                'g'),
        ('c',                 'k'),
        ('g',                 'G'),
        ('dz',                'z'),
        ('^ea$',              'Yea'),
        ('^ei$',              'Yei'),
        ('^el$',              'Yel'),
        ('^ele$',             'Yele'),
        ('^eu$',              'Yeu'),
        ('^era$',             'Yera'),
        ('^erai$',            'Yerai'),
        ('^eram$',            'Yeram'),
        ('^eraTi$',           'YeraTi'),
        ('^erau$',            'Yerau'),
        ('^este$',            'Yeste'),
        ('^eSti$',            'YeSti'),
        ('^ex{@}',            'eGz'),
        ('SS',                'S'),
        ('S{@}',              'sY'),
        ('S',                 'sYu'),
        ('xx',                'x'),
        ('x',                 'ks'),
        ('q',                 'k'),
        ('kh',                'k'),
        ('ph',                'p'),
        ('th',                't'),
        ('w',                 'v'),
        ('^y{@}',             'Y'),
        ('y',                 'i'),
        ('aa',                'a'),
        ('bb',                'b'),
        ('dd',                'd'),
        ('ee',                'e'),
        ('ff',                'f'),
        ('hh',                'h'),
        ('ii',                'i'),
        ('jj',                'j'),
        ('kk',                'k'),
        ('ll',                'l'),
        ('{@}mm{@}',          Jongseong(M), Choseong(M)),
        ('mm',                'm'),
        ('{@}nn{@}',          Jongseong(N), Choseong(N)),
        ('nn',                'n'),
        ('mn$',               'mnI'),
        ('oo',                'o'),
        ('pp',                'p'),
        ('rr',                'r'),
        ('ss',                's'),
        ('tt',                't'),
        ('uu',                'u'),
        ('vv',                'v'),
        ('zz',                'z'),
        ('^k',                Choseong(K)),
        ('{@}k{<voiceless>}', Jongseong(G)),
        ('^p',                Choseong(P)),
        ('{@}p{<voiceless>}', Jongseong(B)),
        ('k',                 Choseong(K)),
        ('p',                 Choseong(P)),
        ('b',                 Choseong(B)),
        ('C',                 Choseong(C)),
        ('d',                 Choseong(D)),
        ('f',                 Choseong(P)),
        ('G',                 Choseong(G)),
        ('h',                 Choseong(H)),
        ('j{@}',              Choseong(J)),
        ('j',                 Choseong(J), Jungseong(I)),
        ('^m',                'P'),
        ('^n',                'Q'),
        ('^l',                Choseong(L)),
        ('{m|n}l',            Choseong(L)),
        ('l{@}',              Jongseong(L), Choseong(L)),
        ('l',                 Jongseong(L)),
        ('P',                 Choseong(M)),
        ('m{@}',              Choseong(M)),
        ('m',                 Jongseong(M)),
        ('Q',                 Choseong(N)),
        ('n{@}',              Choseong(N)),
        ('n',                 Jongseong(N)),
        ('r',                 Choseong(L)),
        ('s',                 Choseong(S)),
        ('t',                 Choseong(T)),
        ('T',                 Choseong(C)),
        ('v',                 Choseong(B)),
        ('z',                 Choseong(J)),
        ('Ya',                Jungseong(YA)),
        ('YA',                Jungseong(YEO)),
        ('Ye',                Jungseong(YE)),
        ('Yi',                Jungseong(I)),
        ('YI',                Jungseong(I), Jungseong(EU)),
        ('Yo',                Jungseong(YO)),
        ('Yu',                Jungseong(YU)),
        ('a',                 Jungseong(A)),
        ('A',                 Jungseong(EO)),
        ('e',                 Jungseong(E)),
        ('i',                 Jungseong(I)),
        ('I',                 Jungseong(EU)),
        ('o',                 Jungseong(O)),
        ('u',                 Jungseong(U))
    ])

    def normalize(self, string):
        return normalize_roman(string, {
            u'Ă': u'ă', u'Â': u'â', u'Ĕ': u'ă', u'ĕ': u'ă', u'Î': u'î',
            u'Ș': u'ș', u'Ş': u'ș', u'ş': u'ș', u'Ț': u'ț', u'Ţ': u'ț',
            u'ţ': u'ț'
        })


__lang__ = Romanian
