# -*- coding: utf-8 -*-
from kss._modules.hangulization.hangulize import *


class Swedish(Language):
    """For transcribing Swedish."""

    __iso639__ = {1: 'sv', 2: 'swe', 3: 'swe'}
    __tmp__ = ',.;'

    vowels = 'a', 'A', 'e', 'E', 'i', 'o', 'O', 'u', 'y'
    vl = 'f', 'h', 'k', 'p', 's', 't'
    notation = Notation([
        # Convention: A = å, E = ä, O = ö
        (u'å',             'A'),
        (u'ä',             'E'),
        (u'ö',             'O'),
        ('w',              'v'),
        ('adjO',           'ajO'),
        ('berg',           'beri'),
        ('borg',           'bori'),
        ('dvErg',          'dvEri'),
        ('fErg',           'fEri'),
        ('karg',           'kari'),
        ('korg',           'kori'),
        ('mErg',           'mEri'),
        ('sorg',           'sori'),
        ('torg',           'tori'),
        ('varg',           'vari'),
        ('norge',          'norje'),
        ('sverige',        'sverije'),
        ('avg{e|i}',       'avj'),
        ('namng{e|i}',     'namnj'),
        ('Aterg{e|i}',     'Aterj'),
        ('Overg{e|i}',     'Overj'),
        ('^igen',          'ijen'),
        ('reger',          'rejer'),
        ('regist',         'rejist'),
        ('gata$',          'Gata'),
        ('gatan$',         'Gatan'),
        ('giva',           'jiva'),
        ('gift',           'jift'),
        ('genom',          'jenom'),
        ('geir',           'Geir'),
        ('gren$',          'Gren'),
        ('grens$',         'Grens'),
        ('guyan',          'Gaian'),
        ('kebnekaise',     'Kebnekaise'),
        ('kelvin',         'Kelvin'),
        ('kelviA',         'KelviA'),
        ('kennet',         'Kennet'),
        ('^keke',          'Keke'),
        ('^kent',          'Kent'),
        ('kexholm',        'Kexholm'),
        ('^kim',           'Kim'),
        ('kiruna',         'Kiruna'),
        ('^kO$',           'KO'),
        ('^bilkO',         'bilKO'),
        ('^kOer$',         'KOer'),
        ('^kOren$',        'KOren'),
        ('^kOrfestival',   'KOrfestival'),
        ('^kymmen',        'Kymmen'),
        ('lysekil',        'lyseSil'),
        ('guyan',          'Gaian'),
        ('mEnnisk',        'mEnniS'),
        ('sjuk',           'sjuk.'), # arbitrary rule
        ('xx',             'x'),
        ('x',              'ks'),
        ('ds',             's'),
        ('sch{@}',         'S'),
        ('sch',            'Su'),
        ('^sk{e|E|i|O|y}', 'S'),
        ('sk{E|O|y}',      'S'),
        ('^sk{e|E|i|O|y}', 'S'),
        ('sk{E|O|y}',      'S'),
        ('skj',            'S'),
        ('stj',            'S'),
        ('kj',             'S'),
        ('sj',             'S'),
        ('ttj',            'ti'),
        ('tj',             'S'),
        ('^g{e|E|i|O|y}',  'j'),
        ('g{E|O|y}',       'j'),
        ('^k{e|E|i|O|y}',  'S'),
        ('k{E|O|y}',       'S'),
        ('ch{@}',          'S'),
        ('ch',             'k'),
        ('c{e|i|y}',       's'),
        ('c',              'k'),
        ('tionde',         'ti.onde'),
        ('tion',           'Son'),
        ('^dj',            'j'),
        ('gj',             'j'),
        ('hj',             'j'),
        ('^lj',            'j'),
        ('lg$',            'li'),
        ('lg{@|l|r}',      'lG'),
        ('lg',             'li'),
        ('rg$',            'ri'),
        ('rg{l|@|r}',      'rG'),
        ('rg',             'ri'),
        ('rl',             'l'),
        ('qu',             'kv'),
        ('q',              'k'),
        ('{@}gn',          'Nn'),
        ('ng',             'N'),
        ('nkt',            'Nt'),
        ('nk',             'Nk'),
        ('mn{@}',          'm,n'),
        ('Nn{@}',          'N,n'),
        ('{m|N}n',         None),
        ('th',             't'),
        ('z',              's'),
        ('jO',             'je'),
        ('SO',             'Se'),
        ('S{@}',           'sJ'),
        ('S',              'si'),
        ('^j{@}',          'J'),
        ('{@}j{@}',        'J'),
        ('j',              'i'),
        ('G',              'g'),
        ('K',              'k'),
        ('aa',             'a'),
        ('bb',             'b'),
        ('dd',             'd'),
        ('ee',             'e'),
        ('ff',             'f'),
        ('gg',             'g'),
        ('hh',             'h'),
        ('ii',             'i'),
        ('jj',             'j'),
        ('kk',             'k'),
        ('ll',             'l'),
        ('{@}mm{@}',       'm,m'),
        ('mm',             'm'),
        ('{@}nn{@}',       'n,n'),
        ('nn',             'n'),
        ('oo',             'o'),
        ('pp',             'p'),
        ('rr',             'r'),
        ('ss',             's'),
        ('tt',             't'),
        ('uu',             'u'),
        ('vv',             'v'),
        ('yy',             'y'),
        ('zz',             'z'),
        ('A',              'o'),
        ('E',              'e'),
        ('h{@}',           'H'),
        ('h',              None),
        ('H',              'h'),
        ('{@}b{<vl>}',     'p,'),
        ('{@}g{<vl>}',     'k,'),
        ('{@}k{<vl>}',     'k,'),
        ('{@}p{<vl>}',     'p,'),
        ('{@}t{<vl>}',     't,'),
        ('^l',             'l;'),
        ('^m',             'm;'),
        ('^n',             'n;'),
        ('l$',             'l,'),
        ('m$',             'm,'),
        ('n$',             'n,'),
        ('l{@|m,|n,|N}',   'l;'),
        ('{,}l',           'l;'),
        ('m{@}',           'm;'),
        ('n{@}',           'n;'),
        ('l',              'l,'),
        ('m',              'm,'),
        ('n',              'n,'),
        ('N',              'N,'),
        (',,',             ','),
        (',;',             None),
        (',l,',            'l,'),
        (',m,',            'm,'),
        (',n,',            'n,'),
        (',N,',            'N,'),
        ('l{m;|n;}',       'l,'),
        (';',              None),
        ('b',              Choseong(B)),
        ('d',              Choseong(D)),
        ('f',              Choseong(P)),
        ('g',              Choseong(G)),
        ('h',              Choseong(H)),
        ('k,',             Jongseong(G)),
        ('k',              Choseong(K)),
        ('^l',             Choseong(L)),
        ('{,}l',           Choseong(L)),
        ('l,',             Jongseong(L)),
        ('l',              Jongseong(L), Choseong(L)),
        ('m,',             Jongseong(M)),
        ('m',              Choseong(M)),
        ('n,',             Jongseong(N)),
        ('n',              Choseong(N)),
        ('N',              Jongseong(NG)),
        ('p,',             Jongseong(B)),
        ('p',              Choseong(P)),
        ('r',              Choseong(L)),
        ('s',              Choseong(S)),
        ('t,',             Jongseong(S)),
        ('t',              Choseong(T)),
        ('v',              Choseong(B)),
        ('Ja',             Jungseong(YA)),
        ('Je',             Jungseong(YE)),
        ('Ji',             Jungseong(I)),
        ('Jo',             Jungseong(YO)),
        ('Ju',             Jungseong(YU)),
        ('Jy',             Jungseong(WI)),
        ('a',              Jungseong(A)),
        ('e',              Jungseong(E)),
        ('i',              Jungseong(I)),
        ('o',              Jungseong(O)),
        ('u',              Jungseong(U)),
        ('y',              Jungseong(WI)),
        ('O',              Jungseong(OE)),
    ])

    def normalize(self, string):
        return normalize_roman(string, {
            u'Å': u'å', u'Ǻ': u'å', u'ǻ': u'å', u'Ä': u'ä', u'Ö': u'ö',
            u'Æ': u'ä', u'æ': u'ä', u'Ø': u'ö', u'ø': u'ö', u'Ç': 's',
            u'ç': 's', u'Ü': 'y', u'ü': 'y'
        })


__lang__ = Swedish
